// ======================================================================
//
// MultiAppear.cpp
// jeff grills
//
// copyright 1997 origin systems inc
//
// ======================================================================

#include "First.h"
#include "MultiAppear.h"

#include "Extents.h"
#include "Game.h"
#include "Iff.h"

// ======================================================================

MultiAppear::MultiAppear(AppearId newId, const char *newName, Iff *iff, real newScale)
: Appear(newId, newName, newScale)
{
	frame = NULL;
	maxFrame = 0;

	if (iff)
		load(name, *iff, scale);
}

// ----------------------------------------------------------------------

MultiAppear::~MultiAppear(void)
{
	if (frame)
	{
		int i;

		for (i = 0; i < maxFrame; i++)
			if (frame[i])
				Appear::removeUser(frame[i]);

		delete [] frame;
		frame = NULL;
	}
	
	maxFrame = 0;
}

// ----------------------------------------------------------------------

void MultiAppear::realAlter(real time)
{
	int i;

	if (frame)
		for (i = 0; i < maxFrame; i++)
			if (frame[i])
				frame[i]->alter(time);
}

// ----------------------------------------------------------------------

void MultiAppear::load(const char *newName, Iff &iff, real newScale)
{
	int   i;

	// figure out how many blocks there are
	maxFrame = iff.blockCount();
	frame	= NEW Appear*[maxFrame];

	// load all the appearances
	for (i = 0; i < maxFrame; i++)
	{
		frame[i]  = Appear::addUser(Game::createAppear(newName, iff, newScale));
		
		if (frame[i] && frame[i]->alterRequired())
			needsRealAlter = true;
	}
}

// ----------------------------------------------------------------------

void MultiAppear::setHardPoints(HardPoints *newHardPoints)
{
	int i;

	Appear::setHardPoints(newHardPoints);

	// force our hardpoint info onto all the frames
	if (frame)
		for (i = 0; i < maxFrame; i++)
			if (frame[i])
				frame[i]->setHardPoints(hardPoints);
}

// ----------------------------------------------------------------------

void MultiAppear::setExtents(Extents *newExtents)
{
	int i;

	Appear::setExtents(newExtents);

	// force our extent info onto all the frames
	if (frame)
		for (i = 0; i < maxFrame; i++)
			if (frame[i])
				frame[i]->setExtents(extents);
}

// ======================================================================
